@@ -8,7 +8,7 @@ from eth_typing import HexStr
 
 from .types import is_string, is_text
 
-_HEX_REGEXP = re.compile("(0x)?[0-9a-f]*", re.IGNORECASE | re.ASCII)
+_HEX_REGEXP = re.compile("(0[xX])?[0-9a-fA-F]*")
 
 
 def decode_hex(value: str) -> bytes:
@@ -37,7 +37,7 @@ def is_0x_prefixed(value: str) -> bool:
         raise TypeError(
             "is_0x_prefixed requires text typed arguments. Got: {0}".format(repr(value))
         )
-    return value.startswith("0x") or value.startswith("0X")
+    return value.startswith(("0x", "0X"))
 
 
 def remove_0x_prefix(value: HexStr) -> HexStr:
